Calendar and Date Operators
===========================

Tooling that deals with calendars and dates.

These items are found in the module ``hg_systematic.operators``.

Calendars
---------

These services, operators and data structures related to working with Calendar data.

.. autoclass:: hg_systematic.operators.HolidayCalendarSchema

.. autofunction:: hg_systematic.operators.calendar_for

.. autoattribute:: hg_systematic.operators.HolidayCalendar


